Metadata

Type Alias Metadata 

pub type Metadata = Metadata;
Type alias of crate::Metadata

Aliased Type

pub struct Metadata {
    pub background_color: Rgba<u8>,
    pub background: Background,
    pub radii: String,
    pub name: String,
    pub author: String,
    pub switch: Switch,
    pub plate_mount: bool,
    pub pcb_mount: bool,
    pub notes: String,
}

Fields

background_color: Rgba<u8>

Background colour for the layout.

background: Background

Background style information for the layout.

radii: String

Corner radii for the background using CSS border-radius syntax.

name: String

The name of the layout.

author: String

The author of the layout.

switch: Switch

The default switch type used in this layout. This can be set separately for individual keys.

plate_mount: bool

Whether the switch is plate mounted.

pcb_mount: bool

Whether the switch is PCB mounted.

notes: String

Notes for the layout. KLE expects GitHub-flavoured Markdown and can render this using the preview button, but any string data is considered valid.