Struct kle_serial::Legend
source · pub struct Legend {
pub text: String,
pub size: usize,
pub color: Color,
}Expand description
A struct representing a single legend.
Note: This is called a label in the official TypeScript kle-serial library and some
other deserialisation libraries. It is called Legend here to follow the common terminology
and match KLE’s own UI.
Fields
text: StringThe legend’s text.
size: usizeThe legend size (in KLE’s font size unit).
color: ColorThe legend colour.