pub type Metadata = Metadata;Expand description
Type alias of crate::Metadata
Aliased Type
pub struct Metadata {
pub background_color: Rgba<u8>,
pub background: Background,
pub radii: String,
pub name: String,
pub author: String,
pub switch: Switch,
pub plate_mount: bool,
pub pcb_mount: bool,
pub notes: String,
}Fields
background_color: Rgba<u8>Background colour for the layout.
background: BackgroundBackground style information for the layout.
radii: StringCorner radii for the background using CSS border-radius syntax.
name: StringThe name of the layout.
The author of the layout.
switch: SwitchThe default switch type used in this layout. This can be set separately for individual keys.
plate_mount: boolWhether the switch is plate mounted.
pcb_mount: boolWhether the switch is PCB mounted.
notes: StringNotes for the layout. KLE expects GitHub-flavoured Markdown and can render this using the preview button, but any string data is considered valid.